# README

This dataset is a BIDS compatible version of the TUH dataset. It reorganizes the file structure to comply with the BIDS specification. To this effect:

- Metadata was organized according to BIDS.
- Data in the EEG edf files was modified to keep only the 19 channels from a 10-20 EEG system.
- Annotations were formatted as BIDS-score compatible `tsv` files.

## Details related to access to the data

### License

The dataset is released under the original TUH license. It is a restrictive license which requires a data sharing agreement with TUH to access the files.

### Contact person

The original SeizeIT dataset was published by Joseph Picone. This BIDS compatible version of the dataset was published by [Jonathan Dan](mailto:jonathan.dan@epfl.ch) - [ORCiD 0000-0002-2338-572X](https://orcid.org/0000-0002-2338-572X).

### Practical information to access the data

The original TUH dataset is available on the [TUH website](https://isip.piconepress.com/projects/tuh_eeg/downloads/tuh_eeg_seizure/).

## Overview

### Project name

TUH EEG Seizure Corpus
